==> openbazaar-0.0.1.tar.gz: openbazaar-0.0.1/lib/catalog/classes/_yamato.php <==
<?php
/*
  $Id: _yamato.php,v 1.1.2.2 2003/09/29 03:39:07 tumf Exp $

  Yamato Shipping Calculator.
  Calculate shipping costs.

  2002/03/30 written by TAMURA Toshihiko (tamura@bitscope.co.jp)
  2003/04/12 modified for ms1
 */
/*
    $rate = new _Yamato('yamato','');
    $rate->SetOrigin('01', 'JP');   // ̳ƻ
    $rate->SetDest('13', 'JP');     // Ԥޤ
    $rate->SetWeight(10);           // kg
    $quote = $rate->GetQuote();
    print $quote['type'] . "<br>";
    print $quote['cost'] . "\n";
*/
class _Yamato {
    var $quote;
    var $OriginZone;
    var $OriginCountryCode = 'JP';
    var $DestZone;
    var $DestCountryCode = 'JP';
    var $Weight = 0;
    var $Length = 0;
    var $Width  = 0;
    var $Height = 0;

    // 󥹥ȥ饯
    // $id:   module id
    // $titl: module name
    // $zone: ƻܸ '01''47'
    // $country: country code
    function _Yamato($id, $title, $zone = NULL, $country = NULL) {
        $this->quote = array('id' => $id, 'title' => $title);
        if($zone) {
            $this->SetOrigin($zone, $country);
        }
    }
    // ȯ򥻥åȤ
    // $zone: ƻܸ '01''47'
    // $country: country code
    function SetOrigin($zone, $country = NULL) {
        $this->OriginZone = $zone;
        if($country) {
            $this->OriginCountryCode = $country;
        }
    }
    function SetDest($zone, $country = NULL) {
        $this->DestZone = $zone;
        if($country) {
            $this->DestCountryCode = $country;
        }
    }
    function SetWeight($weight) {
        $this->Weight = $weight;
    }
    function SetSize($length = NULL, $width = NULL, $height = NULL) {
        if($length) {
            $this->Length = $length;
        }
        if($width) {
            $this->Width = $width;
        }
        if($height) {
            $this->Height = $height;
        }
    }
    // ʬ(04)֤
    // ʳξ9֤
    //
    // ʬ  ̾  շ   
    // ----------------------------------
    // 0     60  60cmޤ  2kgޤ
    // 1     80  80cmޤ  5kgޤ
    // 2    100 100cmޤ 10kgޤ
    // 3    120 120cmޤ 15kgޤ
    // 4    140 140cmޤ 20kgޤ
    // 5    160 160cmޤ 25kgޤ
    // 9    ʳ    
    function GetSizeClass() {
        $a_classes = array(
            array(0,  60,  2),  // ʬ,շ,
            array(1,  80,  5),
            array(2, 100, 10),
            array(3, 120, 15),
            array(4, 140, 20),
            array(5, 160, 25)
        );

        $n_totallength = $this->Length + $this->Width + $this->Height;

        while (list($n_index, $a_limit) = each($a_classes)) {
            if ($n_totallength <= $a_limit[1] && $this->Weight <= $a_limit[2]) {
                return $a_limit[0];
            }
        }
        return -1;  // ʳ
    }
    // ո褫饭
    //
    function GetDistKey() {
        $s_key = '';
        $s_z1 = $this->GetLZone($this->OriginZone);
        $s_z2 = $this->GetLZone($this->DestZone);
        if ( $s_z1 && $s_z2 ) {
            // ӥɤ򥢥ե٥åȽϢ뤹
            if ( ord($s_z1) < ord($s_z2) ) {
                $s_key = $s_z1 . $s_z2;
            } else {
                $s_key = $s_z2 . $s_z1;
            }
        }
        return $s_key;
    }
    // ƻܸɤӥɤ
    // $zone: ƻܸ
    function GetLZone($zone) {
        // ƻܸɤӥ('A''L')Ѵ
        //  ̳ƻ:'A' = ̳ƻ
        //  :'B' = Ŀ,긩,ĸ
        //  :'C' = ܾ븩,,ʡ縩
        //    :'D' = 븩,ڸ,ϸ,̸,ո,,,
        //    :'E' = 㸩,Ĺ
        //    :'F' = 츩,Ų,θ,Ÿ
        //  Φ  :'G' = ٻ,,ʡ温
        //    :'H' = 츩,,,ʼ˸,ɸ,²λ
        //    :'I' = Ļ踩,纬,,縩,
        //  ͹  :'J' = 縩,,ɲ,θ
        //  彣  :'K' = ʡ,츩,Ĺ긩,ʬ,ܸ,ܺ긩,縩
        //    :'L' = 츩
        $a_zonemap = array(
        '01'=>'A',  // ̳ƻ
        '02'=>'B',  // Ŀ
        '03'=>'B',  // 긩
        '04'=>'C',  // ܾ븩
        '05'=>'B',  // ĸ
        '06'=>'C',  // 
        '07'=>'C',  // ʡ縩
        '08'=>'D',  // 븩
        '09'=>'D',  // ڸ
        '10'=>'D',  // ϸ
        '11'=>'D',  // ̸
        '12'=>'D',  // ո
        '13'=>'D',  // 
        '14'=>'D',  // 
        '15'=>'E',  // 㸩
        '16'=>'G',  // ٻ
        '17'=>'G',  // 
        '18'=>'G',  // ʡ温
        '19'=>'D',  // 
        '20'=>'E',  // Ĺ
        '21'=>'F',  // 츩
        '22'=>'F',  // Ų
        '23'=>'F',  // θ
        '24'=>'F',  // Ÿ
        '25'=>'H',  // 츩
        '26'=>'H',  // 
        '27'=>'H',  // 
        '28'=>'H',  // ʼ˸
        '29'=>'H',  // ɸ
        '30'=>'H',  // ²λ
        '31'=>'I',  // Ļ踩
        '32'=>'I',  // 纬
        '33'=>'I',  // 
        '34'=>'I',  // 縩
        '35'=>'I',  // 
        '36'=>'J',  // 縩
        '37'=>'J',  // 
        '38'=>'J',  // ɲ
        '39'=>'J',  // θ
        '40'=>'K',  // ʡ
        '41'=>'K',  // 츩
        '42'=>'K',  // Ĺ긩
        '43'=>'K',  // ܸ
        '44'=>'K',  // ʬ
        '45'=>'K',  // ܺ긩
        '46'=>'K',  // 縩
        '47'=>'L'   // 츩
        );
        return $a_zonemap[$zone];
    }

    function GetQuote() {
        // Υ̤βʥ: 󥯥 => (60,80,100,120,140,160)
        $a_pricerank = array(
        'N01'=>array( 740, 950,1160,1370,1580,1790),// ̾(01) Υ
        'N02'=>array( 840,1050,1260,1470,1680,1890),// ̾(02)   
        'N03'=>array( 950,1160,1370,1580,1790,2000),// ̾(03)
        'N04'=>array(1050,1260,1470,1680,1890,2100),// ̾(04)
        'N05'=>array(1160,1370,1580,1790,2000,2210),// ̾(05)
        'N06'=>array(1260,1470,1680,1890,2100,2310),// ̾(06)
        'N07'=>array(1370,1580,1790,2000,2210,2420),// ̾(07)
        'N08'=>array(1470,1680,1890,2100,2310,2520),// ̾(08)
        'N09'=>array(1580,1790,2000,2210,2420,2630),// ̾(09)
        'N10'=>array(1680,1890,2100,2310,2520,2730),// ̾(10)
        'N11'=>array(1790,2000,2210,2420,2630,2840),// ̾(11)   
        'N12'=>array(1890,2420,2940,3470,3990,4520) // ̾(12) Υ
        );
        //  - Ӵ֤βʥ
        // () http://partner.kuronekoyamato.co.jp/estimate/all_est.html
        $a_dist_to_rank = array(
        'AA'=>'N01',
        'AB'=>'N03','BB'=>'N01',
        'AC'=>'N04','BC'=>'N01','CC'=>'N01',
        'AD'=>'N05','BD'=>'N02','CD'=>'N01','DD'=>'N01',
        'AE'=>'N05','BE'=>'N02','CE'=>'N01','DE'=>'N01','EE'=>'N01',
        'AF'=>'N06','BF'=>'N03','CF'=>'N02','DF'=>'N01','EF'=>'N01','FF'=>'N01',
        'AG'=>'N06','BG'=>'N03','CG'=>'N02','DG'=>'N01','EG'=>'N01','FG'=>'N01','GG'=>'N01',
        'AH'=>'N08','BH'=>'N04','CH'=>'N03','DH'=>'N02','EH'=>'N02','FH'=>'N01','GH'=>'N01','HH'=>'N01',
        'AI'=>'N09','BI'=>'N05','CI'=>'N05','DI'=>'N03','EI'=>'N03','FI'=>'N02','GI'=>'N02','HI'=>'N01','II'=>'N01',
        'AJ'=>'N10','BJ'=>'N06','CJ'=>'N06','DJ'=>'N04','EJ'=>'N04','FJ'=>'N03','GJ'=>'N03','HJ'=>'N02','IJ'=>'N02','JJ'=>'N01',
        'AK'=>'N11','BK'=>'N07','CK'=>'N07','DK'=>'N05','EK'=>'N05','FK'=>'N03','GK'=>'N03','HK'=>'N02','IK'=>'N01','JK'=>'N02','KK'=>'N01',
        'AL'=>'N12','BL'=>'N09','CL'=>'N08','DL'=>'N06','EL'=>'N07','FL'=>'N06','GL'=>'N07','HL'=>'N06','IL'=>'N06','JL'=>'N06','KL'=>'N05','LL'=>'N01'
        );

        $s_key = $this->GetDistKey();
        if ( $s_key ) {
            $s_rank = $a_dist_to_rank[$s_key];
            if ( $s_rank ) {
                $n_sizeclass = $this->GetSizeClass();
                if ($n_sizeclass < 0) {
                    $this->quote['error'] = MODULE_SHIPPING_YAMATO_TEXT_OVERSIZE;
                } else {
                    $this->quote['cost'] = $a_pricerank[$s_rank][$n_sizeclass];
                }
            //  $this->quote['DEBUG'] = ' zone=' . $this->OriginZone . '=>' . $this->DestZone   //DEBUG
            //                  . ' cost=' . $a_pricerank[$s_rank][$n_sizeclass];           //DEBUG
            } else {
                $this->quote['error'] = MODULE_SHIPPING_YAMATO_TEXT_OUT_OF_AREA . '(' . $s_key .')';
            }
        } else {
            $this->quote['error'] = MODULE_SHIPPING_YAMATO_TEXT_ILLEGAL_ZONE . '(' . $this->OriginZone . '=>' . $this->DestZone . ')';
        }

        return $this->quote;
    }
}
?>

==> openbazaar-0.0.2.tar.gz: openbazaar-0.0.2/lib/catalog/classes/_yamato.php <==
<?php
/*
  $Id: _yamato.php,v 1.1.2.3 2003/12/08 07:56:32 minami Exp $

  Yamato Shipping Calculator.
  Calculate shipping costs.

  2002/03/30 written by TAMURA Toshihiko (tamura@bitscope.co.jp)
  2003/04/12 modified for ms1
  2003/12/03 modified fee tables
 */
/*
    $rate = new _Yamato('yamato','');
    $rate->SetOrigin('01', 'JP');   // ̳ƻ
    $rate->SetDest('13', 'JP');     // Ԥޤ
    $rate->SetWeight(10);           // kg
    $quote = $rate->GetQuote();
    print $quote['type'] . "<br>";
    print $quote['cost'] . "\n";
*/
class _Yamato {
    var $quote;
    var $OriginZone;
    var $OriginCountryCode = 'JP';
    var $DestZone;
    var $DestCountryCode = 'JP';
    var $Weight = 0;
    var $Length = 0;
    var $Width  = 0;
    var $Height = 0;

    // 󥹥ȥ饯
    // $id:   module id
    // $titl: module name
    // $zone: ƻܸ '01''47'
    // $country: country code
    function _Yamato($id, $title, $zone = NULL, $country = NULL) {
        $this->quote = array('id' => $id, 'title' => $title);
        if($zone) {
            $this->SetOrigin($zone, $country);
        }
    }
    // ȯ򥻥åȤ
    // $zone: ƻܸ '01''47'
    // $country: country code
    function SetOrigin($zone, $country = NULL) {
        $this->OriginZone = $zone;
        if($country) {
            $this->OriginCountryCode = $country;
        }
    }
    function SetDest($zone, $country = NULL) {
        $this->DestZone = $zone;
        if($country) {
            $this->DestCountryCode = $country;
        }
    }
    function SetWeight($weight) {
        $this->Weight = $weight;
    }
    function SetSize($length = NULL, $width = NULL, $height = NULL) {
        if($length) {
            $this->Length = $length;
        }
        if($width) {
            $this->Width = $width;
        }
        if($height) {
            $this->Height = $height;
        }
    }
    // ʬ(04)֤
    // ʳξ9֤
    //
    // ʬ  ̾  շ   
    // ----------------------------------
    // 0     60  60cmޤ  2kgޤ
    // 1     80  80cmޤ  5kgޤ
    // 2    100 100cmޤ 10kgޤ
    // 3    120 120cmޤ 15kgޤ
    // 4    140 140cmޤ 20kgޤ
    // 5    160 160cmޤ 25kgޤ
    // 9    ʳ    
    function GetSizeClass() {
        $a_classes = array(
            array(0,  60,  2),  // ʬ,շ,
            array(1,  80,  5),
            array(2, 100, 10),
            array(3, 120, 15),
            array(4, 140, 20),
            array(5, 160, 25)
        );

        $n_totallength = $this->Length + $this->Width + $this->Height;

        while (list($n_index, $a_limit) = each($a_classes)) {
            if ($n_totallength <= $a_limit[1] && $this->Weight <= $a_limit[2]) {
                return $a_limit[0];
            }
        }
        return -1;  // ʳ
    }
    // ո褫饭
    //
    function GetDistKey() {
        $s_key = '';
        $s_z1 = $this->GetLZone($this->OriginZone);
        $s_z2 = $this->GetLZone($this->DestZone);
        if ( $s_z1 && $s_z2 ) {
            // ӥɤ򥢥ե٥åȽϢ뤹
            if ( ord($s_z1) < ord($s_z2) ) {
                $s_key = $s_z1 . $s_z2;
            } else {
                $s_key = $s_z2 . $s_z1;
            }
        }
        return $s_key;
    }
    // ƻܸɤӥɤ
    // $zone: ƻܸ
    function GetLZone($zone) {
        // ƻܸɤӥ('A''L')Ѵ
        //  ̳ƻ:'A' = ̳ƻ
        //  :'B' = Ŀ,긩,ĸ
        //  :'C' = ܾ븩,,ʡ縩
        //    :'D' = 븩,ڸ,ϸ,̸,ո,,,
        //    :'E' = 㸩,Ĺ
        //    :'F' = 츩,Ų,θ,Ÿ
        //  Φ  :'G' = ٻ,,ʡ温
        //    :'H' = 츩,,,ʼ˸,ɸ,²λ
        //    :'I' = Ļ踩,纬,,縩,
        //  ͹  :'J' = 縩,,ɲ,θ
        //  彣  :'K' = ʡ,츩,Ĺ긩,ʬ,ܸ,ܺ긩,縩
        //    :'L' = 츩
        $a_zonemap = array(
        '01'=>'A',  // ̳ƻ
        '02'=>'B',  // Ŀ
        '03'=>'B',  // 긩
        '04'=>'C',  // ܾ븩
        '05'=>'B',  // ĸ
        '06'=>'C',  // 
        '07'=>'C',  // ʡ縩
        '08'=>'D',  // 븩
        '09'=>'D',  // ڸ
        '10'=>'D',  // ϸ
        '11'=>'D',  // ̸
        '12'=>'D',  // ո
        '13'=>'D',  // 
        '14'=>'D',  // 
        '15'=>'E',  // 㸩
        '16'=>'G',  // ٻ
        '17'=>'G',  // 
        '18'=>'G',  // ʡ温
        '19'=>'D',  // 
        '20'=>'E',  // Ĺ
        '21'=>'F',  // 츩
        '22'=>'F',  // Ų
        '23'=>'F',  // θ
        '24'=>'F',  // Ÿ
        '25'=>'H',  // 츩
        '26'=>'H',  // 
        '27'=>'H',  // 
        '28'=>'H',  // ʼ˸
        '29'=>'H',  // ɸ
        '30'=>'H',  // ²λ
        '31'=>'I',  // Ļ踩
        '32'=>'I',  // 纬
        '33'=>'I',  // 
        '34'=>'I',  // 縩
        '35'=>'I',  // 
        '36'=>'J',  // 縩
        '37'=>'J',  // 
        '38'=>'J',  // ɲ
        '39'=>'J',  // θ
        '40'=>'K',  // ʡ
        '41'=>'K',  // 츩
        '42'=>'K',  // Ĺ긩
        '43'=>'K',  // ܸ
        '44'=>'K',  // ʬ
        '45'=>'K',  // ܺ긩
        '46'=>'K',  // 縩
        '47'=>'L'   // 츩
        );
        return $a_zonemap[$zone];
    }

    function GetQuote() {
        // [̾] Υ̤βʥ
        // 󥯥 => (60,80,100,120,140,160)
        $a_pricerank = array(
        'N01'=>array( 740, 950,1160,1370,1580,1790),// (01) Υ
        'N02'=>array( 840,1050,1260,1470,1680,1890),// (02)   
        'N03'=>array( 950,1160,1370,1580,1790,2000),// (03)
        'N04'=>array(1050,1260,1470,1680,1890,2100),// (04)
        'N05'=>array(1160,1370,1580,1790,2000,2210),// (05)
        'N06'=>array(1260,1470,1680,1890,2100,2310),// (06)
        'N07'=>array(1370,1580,1790,2000,2210,2420),// (07)
        'N08'=>array(1470,1680,1890,2100,2310,2520),// (08)
        'N09'=>array(1580,1790,2000,2210,2420,2630),// (09)
        'N10'=>array(1680,1890,2100,2310,2520,2730),// (10)   
        'N11'=>array(1790,2000,2210,2420,2630,2840),// (11) Υ
        'X05'=>array(1160,1680,2210,2730,3260,3780),// 
        'X06'=>array(1260,1790,2310,2840,3360,3890),// 
        'X07'=>array(1370,1890,2420,2940,3470,3990),// 
        'X08'=>array(1470,2000,2520,3050,3570,4100),// 
        'X09'=>array(1580,2100,2630,3150,3680,4200),// 
        'X12'=>array(1890,2420,2940,3470,3990,4520) // 
        );
        //  - Ӵ֤βʥ
        // () http://partner.kuronekoyamato.co.jp/estimate/all_est.html
        $a_dist_to_rank = array(
        'AA'=>'N01',
        'AB'=>'N03','BB'=>'N01',
        'AC'=>'N04','BC'=>'N01','CC'=>'N01',
        'AD'=>'N05','BD'=>'N02','CD'=>'N01','DD'=>'N01',
        'AE'=>'N05','BE'=>'N02','CE'=>'N01','DE'=>'N01','EE'=>'N01',
        'AF'=>'N06','BF'=>'N03','CF'=>'N02','DF'=>'N01','EF'=>'N01','FF'=>'N01',
        'AG'=>'N06','BG'=>'N03','CG'=>'N02','DG'=>'N01','EG'=>'N01','FG'=>'N01','GG'=>'N01',
        'AH'=>'N08','BH'=>'N04','CH'=>'N03','DH'=>'N02','EH'=>'N02','FH'=>'N01','GH'=>'N01','HH'=>'N01',
        'AI'=>'N09','BI'=>'N05','CI'=>'N05','DI'=>'N03','EI'=>'N03','FI'=>'N02','GI'=>'N02','HI'=>'N01','II'=>'N01',
        'AJ'=>'N10','BJ'=>'N06','CJ'=>'N06','DJ'=>'N04','EJ'=>'N04','FJ'=>'N03','GJ'=>'N03','HJ'=>'N02','IJ'=>'N02','JJ'=>'N01',
        'AK'=>'N11','BK'=>'N07','CK'=>'N07','DK'=>'N05','EK'=>'N05','FK'=>'N03','GK'=>'N03','HK'=>'N02','IK'=>'N01','JK'=>'N02','KK'=>'N01',
        'AL'=>'X12','BL'=>'X09','CL'=>'X08','DL'=>'X06','EL'=>'X07','FL'=>'X06','GL'=>'X07','HL'=>'X06','IL'=>'X06','JL'=>'X06','KL'=>'X05','LL'=>'N01'
        );

        $s_key = $this->GetDistKey();
        if ( $s_key ) {
            $s_rank = $a_dist_to_rank[$s_key];
            if ( $s_rank ) {
                $n_sizeclass = $this->GetSizeClass();
                if ($n_sizeclass < 0) {
                    $this->quote['error'] = MODULE_SHIPPING_YAMATO_TEXT_OVERSIZE;
                } else {
                    $this->quote['cost'] = $a_pricerank[$s_rank][$n_sizeclass];
                }
            } else {
                $this->quote['error'] = MODULE_SHIPPING_YAMATO_TEXT_OUT_OF_AREA . '(' . $s_key .')';
            }
        } else {
            $this->quote['error'] = MODULE_SHIPPING_YAMATO_TEXT_ILLEGAL_ZONE . '(' . $this->OriginZone . '=>' . $this->DestZone . ')';
        }

        return $this->quote;
    }
}
?>
